@@ -11,6 +11,7 @@ import re
 import cgi
 import ast
 import json
+from types import GeneratorType
 from jinja2.exceptions import TemplateNotFound
 from etgen.html import E, tostring
 from etgen import html as xghtml
@@ -35,7 +36,7 @@ from lino.core.elems import ComboFieldElement
 from lino.core.fields import choices_for_field
 from lino.core.gfks import ContentType
 from lino.core import constants
-from lino.core.requests import BaseRequest
+from lino.core.requests import BaseRequest, PhantomRow
 from lino.core.tablerequest import TableRequest
 from lino.core.views import requested_actor, action_request
 from lino.core.views import json_response, json_response_kw
@@ -164,7 +165,16 @@ class ApiList(View):
                 def serialize(ar, row):
                     """Use display_mode to determine which serilisation store method and fields to use"""
                     if display_mode == constants.DISPLAY_MODE_TABLE:
-                        return rh.store.row2list(ar, row)
+                        row_classes = None
+                        if ar.actor.get_row_classes is not None and not isinstance(row, PhantomRow):
+                            classes = ar.actor.get_row_classes(row, ar)
+                            if isinstance(classes, GeneratorType):
+                                row_classes = " ".join([klass for klass in classes])
+                            else:
+                                row_classes = classes
+                        rowData = rh.store.row2list(ar, row)
+                        rowData.append(row_classes)
+                        return rowData
                     elif display_mode == constants.DISPLAY_MODE_GALLERY:
                         # return rh.store.file2url(ar, row)
                         return row.get_gallery_item(ar)
@@ -274,7 +284,7 @@ class Choices(View):
 class DelayedValue(View):
     def get(self, request, app_label=None, actor=None, pk=None, field=None, **kw):
         ar = action_request(
-            app_label, actor, request, request.GET, True,
+            app_label, actor, request, request.GET, False,
             renderer=settings.SITE.plugins.react.renderer)
         # print("20210619a", ar)
         # rpt = requested_actor(app_label, actor)
